# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class RetargetingListServiceRuleCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'compare_operator': 'RetargetingListServiceCompareOperator',
        'rule_type': 'RetargetingListServiceRuleType',
        'value': 'str'
    }

    attribute_map = {
        'compare_operator': 'compareOperator',
        'rule_type': 'ruleType',
        'value': 'value'
    }

    def __init__(self, compare_operator=None, rule_type=None, value=None, local_vars_configuration=None):  # noqa: E501
        """RetargetingListServiceRuleCondition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._compare_operator = None
        self._rule_type = None
        self._value = None
        self.discriminator = None

        self.compare_operator = compare_operator
        self.rule_type = rule_type
        self.value = value

    @property
    def compare_operator(self):
        """Gets the compare_operator of this RetargetingListServiceRuleCondition.  # noqa: E501


        :return: The compare_operator of this RetargetingListServiceRuleCondition.  # noqa: E501
        :rtype: RetargetingListServiceCompareOperator
        """
        return self._compare_operator

    @compare_operator.setter
    def compare_operator(self, compare_operator):
        """Sets the compare_operator of this RetargetingListServiceRuleCondition.


        :param compare_operator: The compare_operator of this RetargetingListServiceRuleCondition.  # noqa: E501
        :type: RetargetingListServiceCompareOperator
        """

        self._compare_operator = compare_operator

    @property
    def rule_type(self):
        """Gets the rule_type of this RetargetingListServiceRuleCondition.  # noqa: E501


        :return: The rule_type of this RetargetingListServiceRuleCondition.  # noqa: E501
        :rtype: RetargetingListServiceRuleType
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """Sets the rule_type of this RetargetingListServiceRuleCondition.


        :param rule_type: The rule_type of this RetargetingListServiceRuleCondition.  # noqa: E501
        :type: RetargetingListServiceRuleType
        """

        self._rule_type = rule_type

    @property
    def value(self):
        """Gets the value of this RetargetingListServiceRuleCondition.  # noqa: E501

        <div lang=\"ja\"> ルールで評価する値です。<br> このフィールドは、ADDおよびSET時に必須となり、REMOVE時に無視されます。<br> ※ruleTypeがEVENT_TYPEの場合、以下のイベント種別に記載の値のみ指定可能となります。 </div> <div lang=\"en\"> Matching Rules Value. <br> This field is required in ADD and SET operation, and will be ignored in REMOVE operation.<br> ∗If ruleType is EVENT_TYPE, only the values listed in the table below can be specified. </div> <details>   <summary>     <div lang=\"ja\">イベント種別</div>     <div lang=\"en\">Event Type</div>   </summary>   <table>     <thead>       <tr>         <th>           <div lang=\"ja\">イベント種別</div>           <div lang=\"en\">Event Type</div>         </th>         <th>           <div lang=\"ja\">イベント種別名</div>           <div lang=\"en\">Name of event type</div>         </th>       </tr>     </thead>     <tbody>       <tr>         <td>app_install</td>         <td>           <div lang=\"ja\">アプリをインストール</div>           <div lang=\"en\">App install</div>         </td>       </tr>       <tr>         <td>app_launch</td>         <td>           <div lang=\"ja\">アプリ起動</div>           <div lang=\"en\">App start</div>         </td>       </tr>       <tr>         <td>app_update</td>         <td>           <div lang=\"ja\">アプリをアップデート</div>           <div lang=\"en\">App update</div>         </td>       </tr>       <tr>         <td>view_listing</td>         <td>           <div lang=\"ja\">商品一覧画面の閲覧</div>           <div lang=\"en\">View item list</div>         </td>       </tr>       <tr>         <td>view_product</td>         <td>           <div lang=\"ja\">商品詳細画面の閲覧</div>           <div lang=\"en\">View item description</div>         </td>       </tr>       <tr>         <td>view_cart</td>         <td>           <div lang=\"ja\">商品カートを閲覧</div>           <div lang=\"en\">View cart</div>         </td>       </tr>       <tr>         <td>add_wishlist</td>         <td>           <div lang=\"ja\">お気に入りに追加</div>           <div lang=\"en\">Add to wishlist</div>         </td>       </tr>       <tr>         <td>add_cart</td>         <td>           <div lang=\"ja\">商品カートに追加</div>           <div lang=\"en\">Add to cart</div>         </td>       </tr>       <tr>         <td>check_out</td>         <td>           <div lang=\"ja\">商品購入確認</div>           <div lang=\"en\">Confirm purchasing</div>         </td>       </tr>       <tr>         <td>purchase</td>         <td>           <div lang=\"ja\">商品購入</div>           <div lang=\"en\">Purchase</div>         </td>       </tr>       <tr>         <td>payment_info</td>         <td>           <div lang=\"ja\">お支払い明細を発行</div>           <div lang=\"en\">Payment details</div>         </td>       </tr>       <tr>         <td>sign_up</td>         <td>           <div lang=\"ja\">登録完了</div>           <div lang=\"en\">Registration complete</div>         </td>       </tr>       <tr>         <td>login</td>         <td>           <div lang=\"ja\">ログイン</div>           <div lang=\"en\">Login</div>         </td>       </tr>       <tr>         <td>search</td>         <td>           <div lang=\"ja\">検索</div>           <div lang=\"en\">Search</div>         </td>       </tr>       <tr>         <td>review</td>         <td>           <div lang=\"ja\">コンテンツをレビュー</div>           <div lang=\"en\">Review contents</div>         </td>       </tr>       <tr>         <td>share</td>         <td>           <div lang=\"ja\">コンテンツをシェア</div>           <div lang=\"en\">Share contents</div>         </td>       </tr>       <tr>         <td>invite</td>         <td>           <div lang=\"ja\">アプリへ招待</div>           <div lang=\"en\">Invite to app</div>         </td>       </tr>       <tr>         <td>reservation</td>         <td>           <div lang=\"ja\">予約完了</div>           <div lang=\"en\">Reservation complete</div>         </td>       </tr>       <tr>         <td>tutorial</td>         <td>           <div lang=\"ja\">チュートリアルを完了</div>           <div lang=\"en\">Tutorial complete</div>         </td>       </tr>       <tr>         <td>deeplink</td>         <td>           <div lang=\"ja\">ディープリンクから流入</div>           <div lang=\"en\">Traffic from deep link</div>         </td>       </tr>       <tr>         <td>start_level</td>         <td>           <div lang=\"ja\">ゲームイベントを開始</div>           <div lang=\"en\">Start game event</div>         </td>       </tr>       <tr>         <td>end_level</td>         <td>           <div lang=\"ja\">ゲームイベントを完了</div>           <div lang=\"en\">End game event</div>         </td>       </tr>       <tr>         <td>level_achieved</td>         <td>           <div lang=\"ja\">ゲームのレベル到達</div>           <div lang=\"en\">Level achieved</div>         </td>       </tr>       <tr>         <td>unlock_achievement</td>         <td>           <div lang=\"ja\">ゲームの目標達成</div>           <div lang=\"en\">Unlock achievement</div>         </td>       </tr>       <tr>         <td>app_purchase</td>         <td>           <div lang=\"ja\">アプリ内購入</div>           <div lang=\"en\">App purchasing</div>         </td>       </tr>       <tr>         <td>spent_credits</td>         <td>           <div lang=\"ja\">クレジットカードの利用</div>           <div lang=\"en\">Credit card</div>         </td>       </tr>       <tr>         <td>custom1</td>         <td>           <div lang=\"ja\">カスタムイベント1</div>           <div lang=\"en\">Custom event 1</div>         </td>       </tr>       <tr>         <td>custom2</td>         <td>           <div lang=\"ja\">カスタムイベント2</div>           <div lang=\"en\">Custom event 2</div>         </td>       </tr>       <tr>         <td>custom3</td>         <td>           <div lang=\"ja\">カスタムイベント3</div>           <div lang=\"en\">Custom event 3</div>         </td>       </tr>     </tbody>   </table> </details>   # noqa: E501

        :return: The value of this RetargetingListServiceRuleCondition.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this RetargetingListServiceRuleCondition.

        <div lang=\"ja\"> ルールで評価する値です。<br> このフィールドは、ADDおよびSET時に必須となり、REMOVE時に無視されます。<br> ※ruleTypeがEVENT_TYPEの場合、以下のイベント種別に記載の値のみ指定可能となります。 </div> <div lang=\"en\"> Matching Rules Value. <br> This field is required in ADD and SET operation, and will be ignored in REMOVE operation.<br> ∗If ruleType is EVENT_TYPE, only the values listed in the table below can be specified. </div> <details>   <summary>     <div lang=\"ja\">イベント種別</div>     <div lang=\"en\">Event Type</div>   </summary>   <table>     <thead>       <tr>         <th>           <div lang=\"ja\">イベント種別</div>           <div lang=\"en\">Event Type</div>         </th>         <th>           <div lang=\"ja\">イベント種別名</div>           <div lang=\"en\">Name of event type</div>         </th>       </tr>     </thead>     <tbody>       <tr>         <td>app_install</td>         <td>           <div lang=\"ja\">アプリをインストール</div>           <div lang=\"en\">App install</div>         </td>       </tr>       <tr>         <td>app_launch</td>         <td>           <div lang=\"ja\">アプリ起動</div>           <div lang=\"en\">App start</div>         </td>       </tr>       <tr>         <td>app_update</td>         <td>           <div lang=\"ja\">アプリをアップデート</div>           <div lang=\"en\">App update</div>         </td>       </tr>       <tr>         <td>view_listing</td>         <td>           <div lang=\"ja\">商品一覧画面の閲覧</div>           <div lang=\"en\">View item list</div>         </td>       </tr>       <tr>         <td>view_product</td>         <td>           <div lang=\"ja\">商品詳細画面の閲覧</div>           <div lang=\"en\">View item description</div>         </td>       </tr>       <tr>         <td>view_cart</td>         <td>           <div lang=\"ja\">商品カートを閲覧</div>           <div lang=\"en\">View cart</div>         </td>       </tr>       <tr>         <td>add_wishlist</td>         <td>           <div lang=\"ja\">お気に入りに追加</div>           <div lang=\"en\">Add to wishlist</div>         </td>       </tr>       <tr>         <td>add_cart</td>         <td>           <div lang=\"ja\">商品カートに追加</div>           <div lang=\"en\">Add to cart</div>         </td>       </tr>       <tr>         <td>check_out</td>         <td>           <div lang=\"ja\">商品購入確認</div>           <div lang=\"en\">Confirm purchasing</div>         </td>       </tr>       <tr>         <td>purchase</td>         <td>           <div lang=\"ja\">商品購入</div>           <div lang=\"en\">Purchase</div>         </td>       </tr>       <tr>         <td>payment_info</td>         <td>           <div lang=\"ja\">お支払い明細を発行</div>           <div lang=\"en\">Payment details</div>         </td>       </tr>       <tr>         <td>sign_up</td>         <td>           <div lang=\"ja\">登録完了</div>           <div lang=\"en\">Registration complete</div>         </td>       </tr>       <tr>         <td>login</td>         <td>           <div lang=\"ja\">ログイン</div>           <div lang=\"en\">Login</div>         </td>       </tr>       <tr>         <td>search</td>         <td>           <div lang=\"ja\">検索</div>           <div lang=\"en\">Search</div>         </td>       </tr>       <tr>         <td>review</td>         <td>           <div lang=\"ja\">コンテンツをレビュー</div>           <div lang=\"en\">Review contents</div>         </td>       </tr>       <tr>         <td>share</td>         <td>           <div lang=\"ja\">コンテンツをシェア</div>           <div lang=\"en\">Share contents</div>         </td>       </tr>       <tr>         <td>invite</td>         <td>           <div lang=\"ja\">アプリへ招待</div>           <div lang=\"en\">Invite to app</div>         </td>       </tr>       <tr>         <td>reservation</td>         <td>           <div lang=\"ja\">予約完了</div>           <div lang=\"en\">Reservation complete</div>         </td>       </tr>       <tr>         <td>tutorial</td>         <td>           <div lang=\"ja\">チュートリアルを完了</div>           <div lang=\"en\">Tutorial complete</div>         </td>       </tr>       <tr>         <td>deeplink</td>         <td>           <div lang=\"ja\">ディープリンクから流入</div>           <div lang=\"en\">Traffic from deep link</div>         </td>       </tr>       <tr>         <td>start_level</td>         <td>           <div lang=\"ja\">ゲームイベントを開始</div>           <div lang=\"en\">Start game event</div>         </td>       </tr>       <tr>         <td>end_level</td>         <td>           <div lang=\"ja\">ゲームイベントを完了</div>           <div lang=\"en\">End game event</div>         </td>       </tr>       <tr>         <td>level_achieved</td>         <td>           <div lang=\"ja\">ゲームのレベル到達</div>           <div lang=\"en\">Level achieved</div>         </td>       </tr>       <tr>         <td>unlock_achievement</td>         <td>           <div lang=\"ja\">ゲームの目標達成</div>           <div lang=\"en\">Unlock achievement</div>         </td>       </tr>       <tr>         <td>app_purchase</td>         <td>           <div lang=\"ja\">アプリ内購入</div>           <div lang=\"en\">App purchasing</div>         </td>       </tr>       <tr>         <td>spent_credits</td>         <td>           <div lang=\"ja\">クレジットカードの利用</div>           <div lang=\"en\">Credit card</div>         </td>       </tr>       <tr>         <td>custom1</td>         <td>           <div lang=\"ja\">カスタムイベント1</div>           <div lang=\"en\">Custom event 1</div>         </td>       </tr>       <tr>         <td>custom2</td>         <td>           <div lang=\"ja\">カスタムイベント2</div>           <div lang=\"en\">Custom event 2</div>         </td>       </tr>       <tr>         <td>custom3</td>         <td>           <div lang=\"ja\">カスタムイベント3</div>           <div lang=\"en\">Custom event 3</div>         </td>       </tr>     </tbody>   </table> </details>   # noqa: E501

        :param value: The value of this RetargetingListServiceRuleCondition.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetargetingListServiceRuleCondition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetargetingListServiceRuleCondition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.ad_group_ad_service_operation import AdGroupAdServiceOperation  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestAdGroupAdServiceOperation(unittest.TestCase):
    """AdGroupAdServiceOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdGroupAdServiceOperation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.ad_group_ad_service_operation.AdGroupAdServiceOperation()  # noqa: E501
        if include_optional :
            return AdGroupAdServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.ad_group_ad.AdGroupAd(
                        account_id = 56,
                        ad = yahoo_ads_display.models.ad_group_ad_service_ad.AdGroupAdServiceAd(
                            ad_type = 'TEXT_LONG_AD1',
                            banner_image_ad = yahoo_ads_display.models.ad_group_ad_service_banner_image_ad.AdGroupAdServiceBannerImageAd(
                                display_url = '0',
                                url = '0', ),
                            banner_video_ad = yahoo_ads_display.models.ad_group_ad_service_banner_video_ad.AdGroupAdServiceBannerVideoAd(
                                display_url = '0',
                                is_remove_video10_sec_beacon_urls = 'TRUE',
                                is_remove_video25_percent_beacon_urls = 'TRUE',
                                is_remove_video3_sec_beacon_urls = 'TRUE',
                                is_remove_video50_percent_beacon_urls = 'TRUE',
                                is_remove_video75_percent_beacon_urls = 'TRUE',
                                is_remove_video_complete_beacon_urls = 'TRUE',
                                is_remove_video_start_beacon_urls = 'TRUE',
                                thumbnail_media_id = 56,
                                url = '0',
                                video10_sec_beacon_urls = [
                                    '0'
                                    ],
                                video25_percent_beacon_urls = [
                                    '0'
                                    ],
                                video3_sec_beacon_urls = [
                                    '0'
                                    ],
                                video50_percent_beacon_urls = [
                                    '0'
                                    ],
                                video75_percent_beacon_urls = [
                                    '0'
                                    ],
                                video_complete_beacon_urls = [
                                    '0'
                                    ],
                                video_start_beacon_urls = [
                                    '0'
                                    ], ),
                            dynamic_ad = yahoo_ads_display.models.ad_group_ad_service_dynamic_ad.AdGroupAdServiceDynamicAd(
                                brand_color = '0',
                                button_text = 'FOR_MORE_INFO',
                                campaign_banner_media_id = 56,
                                campaign_banner_media_id2 = 56,
                                campaign_banner_media_id3 = 56,
                                campaign_banner_media_id4 = 56,
                                campaign_banner_url = '0',
                                display_url = '0',
                                is_remove_campaign_banner_media_id = 'TRUE',
                                is_remove_campaign_banner_media_id2 = 'TRUE',
                                is_remove_campaign_banner_media_id3 = 'TRUE',
                                is_remove_campaign_banner_media_id4 = 'TRUE',
                                is_remove_campaign_banner_url = 'TRUE',
                                logo_media_id = 56,
                                logo_media_id2 = 56,
                                logo_media_id3 = 56,
                                prefix = '0',
                                principal = '0',
                                suffix = '0',
                                url = '0', ),
                            mobile_ad = yahoo_ads_display.models.ad_group_ad_service_mobile_ad.AdGroupAdServiceMobileAd(
                                description = '0',
                                description2 = '0',
                                display_url = '0',
                                headline = '0',
                                mobile_carriers = [
                                    'DOCOMO'
                                    ],
                                url = '0', ),
                            pos_ad = yahoo_ads_display.models.ad_group_ad_service_pos_ad.AdGroupAdServicePosAd(
                                description = '0',
                                url = '0', ),
                            responsive_image_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_image_ad.AdGroupAdServiceResponsiveImageAd(
                                description = '0',
                                display_url = '0',
                                headline = '0',
                                logo_media_id = 56,
                                principal = '0',
                                url = '0', ),
                            responsive_video_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_video_ad.AdGroupAdServiceResponsiveVideoAd(
                                description = '0',
                                display_url = '0',
                                headline = '0',
                                logo_media_id = 56,
                                principal = '0',
                                thumbnail_media_id = 56,
                                url = '0', ),
                            static_frame_ad = yahoo_ads_display.models.ad_group_ad_service_static_frame_ad.AdGroupAdServiceStaticFrameAd(
                                color_set_id = 56,
                                description = '0',
                                display_url = '0',
                                headline = '0',
                                layout = '0',
                                logo_media_id = 56,
                                principal = '0',
                                size = '0',
                                url = '0', ),
                            text_ad = yahoo_ads_display.models.ad_group_ad_service_text_ad.AdGroupAdServiceTextAd(
                                description = '0',
                                description2 = '0',
                                display_url = '0',
                                headline = '0',
                                url = '0', ), ),
                        ad_group_id = 56,
                        ad_group_name = '0',
                        ad_id = 56,
                        ad_name = '0',
                        ad_style = 'TEXT',
                        approval_status = 'APPROVED',
                        bid = yahoo_ads_display.models.ad_group_ad_service_bid.AdGroupAdServiceBid(
                            bidding_strategy_type = 'MANUAL_CPC',
                            manual_cpc_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpc_ad_group_ad_bid.AdGroupAdServiceManualCPCAdGroupAdBid(
                                max_cpc = 56, ),
                            manual_cpv_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpv_ad_group_ad_bid.AdGroupAdServiceManualCPVAdGroupAdBid(
                                max_cpv = 56, ), ),
                        campaign_id = 56,
                        campaign_name = '0',
                        disapproval_reason_codes = [
                            '0'
                            ],
                        impression_beacon_urls = [
                            '0'
                            ],
                        is_remove_beacon_urls = 'TRUE',
                        is_remove_third_party_tracking_script_url = 'TRUE',
                        labels = [
                            yahoo_ads_display.models.ad_group_ad_service_label.AdGroupAdServiceLabel(
                                color = '0',
                                description = '0',
                                label_id = 56,
                                label_name = '0', )
                            ],
                        media_id = 56,
                        third_party_tracking_script_url = '0',
                        third_party_tracking_vendor = '0',
                        user_status = 'ACTIVE', )
                    ]
            )
        else :
            return AdGroupAdServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.ad_group_ad.AdGroupAd(
                        account_id = 56,
                        ad = yahoo_ads_display.models.ad_group_ad_service_ad.AdGroupAdServiceAd(
                            ad_type = 'TEXT_LONG_AD1',
                            banner_image_ad = yahoo_ads_display.models.ad_group_ad_service_banner_image_ad.AdGroupAdServiceBannerImageAd(
                                display_url = '0',
                                url = '0', ),
                            banner_video_ad = yahoo_ads_display.models.ad_group_ad_service_banner_video_ad.AdGroupAdServiceBannerVideoAd(
                                display_url = '0',
                                is_remove_video10_sec_beacon_urls = 'TRUE',
                                is_remove_video25_percent_beacon_urls = 'TRUE',
                                is_remove_video3_sec_beacon_urls = 'TRUE',
                                is_remove_video50_percent_beacon_urls = 'TRUE',
                                is_remove_video75_percent_beacon_urls = 'TRUE',
                                is_remove_video_complete_beacon_urls = 'TRUE',
                                is_remove_video_start_beacon_urls = 'TRUE',
                                thumbnail_media_id = 56,
                                url = '0',
                                video10_sec_beacon_urls = [
                                    '0'
                                    ],
                                video25_percent_beacon_urls = [
                                    '0'
                                    ],
                                video3_sec_beacon_urls = [
                                    '0'
                                    ],
                                video50_percent_beacon_urls = [
                                    '0'
                                    ],
                                video75_percent_beacon_urls = [
                                    '0'
                                    ],
                                video_complete_beacon_urls = [
                                    '0'
                                    ],
                                video_start_beacon_urls = [
                                    '0'
                                    ], ),
                            dynamic_ad = yahoo_ads_display.models.ad_group_ad_service_dynamic_ad.AdGroupAdServiceDynamicAd(
                                brand_color = '0',
                                button_text = 'FOR_MORE_INFO',
                                campaign_banner_media_id = 56,
                                campaign_banner_media_id2 = 56,
                                campaign_banner_media_id3 = 56,
                                campaign_banner_media_id4 = 56,
                                campaign_banner_url = '0',
                                display_url = '0',
                                is_remove_campaign_banner_media_id = 'TRUE',
                                is_remove_campaign_banner_media_id2 = 'TRUE',
                                is_remove_campaign_banner_media_id3 = 'TRUE',
                                is_remove_campaign_banner_media_id4 = 'TRUE',
                                is_remove_campaign_banner_url = 'TRUE',
                                logo_media_id = 56,
                                logo_media_id2 = 56,
                                logo_media_id3 = 56,
                                prefix = '0',
                                principal = '0',
                                suffix = '0',
                                url = '0', ),
                            mobile_ad = yahoo_ads_display.models.ad_group_ad_service_mobile_ad.AdGroupAdServiceMobileAd(
                                description = '0',
                                description2 = '0',
                                display_url = '0',
                                headline = '0',
                                mobile_carriers = [
                                    'DOCOMO'
                                    ],
                                url = '0', ),
                            pos_ad = yahoo_ads_display.models.ad_group_ad_service_pos_ad.AdGroupAdServicePosAd(
                                description = '0',
                                url = '0', ),
                            responsive_image_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_image_ad.AdGroupAdServiceResponsiveImageAd(
                                description = '0',
                                display_url = '0',
                                headline = '0',
                                logo_media_id = 56,
                                principal = '0',
                                url = '0', ),
                            responsive_video_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_video_ad.AdGroupAdServiceResponsiveVideoAd(
                                description = '0',
                                display_url = '0',
                                headline = '0',
                                logo_media_id = 56,
                                principal = '0',
                                thumbnail_media_id = 56,
                                url = '0', ),
                            static_frame_ad = yahoo_ads_display.models.ad_group_ad_service_static_frame_ad.AdGroupAdServiceStaticFrameAd(
                                color_set_id = 56,
                                description = '0',
                                display_url = '0',
                                headline = '0',
                                layout = '0',
                                logo_media_id = 56,
                                principal = '0',
                                size = '0',
                                url = '0', ),
                            text_ad = yahoo_ads_display.models.ad_group_ad_service_text_ad.AdGroupAdServiceTextAd(
                                description = '0',
                                description2 = '0',
                                display_url = '0',
                                headline = '0',
                                url = '0', ), ),
                        ad_group_id = 56,
                        ad_group_name = '0',
                        ad_id = 56,
                        ad_name = '0',
                        ad_style = 'TEXT',
                        approval_status = 'APPROVED',
                        bid = yahoo_ads_display.models.ad_group_ad_service_bid.AdGroupAdServiceBid(
                            bidding_strategy_type = 'MANUAL_CPC',
                            manual_cpc_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpc_ad_group_ad_bid.AdGroupAdServiceManualCPCAdGroupAdBid(
                                max_cpc = 56, ),
                            manual_cpv_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpv_ad_group_ad_bid.AdGroupAdServiceManualCPVAdGroupAdBid(
                                max_cpv = 56, ), ),
                        campaign_id = 56,
                        campaign_name = '0',
                        disapproval_reason_codes = [
                            '0'
                            ],
                        impression_beacon_urls = [
                            '0'
                            ],
                        is_remove_beacon_urls = 'TRUE',
                        is_remove_third_party_tracking_script_url = 'TRUE',
                        labels = [
                            yahoo_ads_display.models.ad_group_ad_service_label.AdGroupAdServiceLabel(
                                color = '0',
                                description = '0',
                                label_id = 56,
                                label_name = '0', )
                            ],
                        media_id = 56,
                        third_party_tracking_script_url = '0',
                        third_party_tracking_vendor = '0',
                        user_status = 'ACTIVE', )
                    ],
        )

    def testAdGroupAdServiceOperation(self):
        """Test AdGroupAdServiceOperation"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from yahoo_ads_display.api.account_ad_product_service_api import AccountAdProductServiceApi
from yahoo_ads_display.api.account_service_api import AccountServiceApi
from yahoo_ads_display.api.ad_group_ad_label_service_api import AdGroupAdLabelServiceApi
from yahoo_ads_display.api.ad_group_ad_service_api import AdGroupAdServiceApi
from yahoo_ads_display.api.ad_group_label_service_api import AdGroupLabelServiceApi
from yahoo_ads_display.api.ad_group_service_api import AdGroupServiceApi
from yahoo_ads_display.api.ad_group_target_service_api import AdGroupTargetServiceApi
from yahoo_ads_display.api.audit_log_service_api import AuditLogServiceApi
from yahoo_ads_display.api.balance_service_api import BalanceServiceApi
from yahoo_ads_display.api.campaign_label_service_api import CampaignLabelServiceApi
from yahoo_ads_display.api.campaign_migration_service_api import CampaignMigrationServiceApi
from yahoo_ads_display.api.campaign_service_api import CampaignServiceApi
from yahoo_ads_display.api.conversion_tracker_service_api import ConversionTrackerServiceApi
from yahoo_ads_display.api.dictionary_service_api import DictionaryServiceApi
from yahoo_ads_display.api.feed_data_service_api import FeedDataServiceApi
from yahoo_ads_display.api.feed_ftp_request_service_api import FeedFtpRequestServiceApi
from yahoo_ads_display.api.feed_ftp_service_api import FeedFtpServiceApi
from yahoo_ads_display.api.feed_item_service_api import FeedItemServiceApi
from yahoo_ads_display.api.feed_service_api import FeedServiceApi
from yahoo_ads_display.api.feed_set_service_api import FeedSetServiceApi
from yahoo_ads_display.api.label_service_api import LabelServiceApi
from yahoo_ads_display.api.media_service_api import MediaServiceApi
from yahoo_ads_display.api.placement_url_idea_service_api import PlacementUrlIdeaServiceApi
from yahoo_ads_display.api.placement_url_list_service_api import PlacementUrlListServiceApi
from yahoo_ads_display.api.report_definition_service_api import ReportDefinitionServiceApi
from yahoo_ads_display.api.retargeting_list_service_api import RetargetingListServiceApi
from yahoo_ads_display.api.retargeting_tag_service_api import RetargetingTagServiceApi
from yahoo_ads_display.api.search_keyword_idea_service_api import SearchKeywordIdeaServiceApi
from yahoo_ads_display.api.search_keyword_list_service_api import SearchKeywordListServiceApi
from yahoo_ads_display.api.stats_service_api import StatsServiceApi
from yahoo_ads_display.api.video_service_api import VideoServiceApi

# import ApiClient
from yahoo_ads_display.api_client import ApiClient
from yahoo_ads_display.configuration import Configuration
from yahoo_ads_display.exceptions import OpenApiException
from yahoo_ads_display.exceptions import ApiTypeError
from yahoo_ads_display.exceptions import ApiValueError
from yahoo_ads_display.exceptions import ApiKeyError
from yahoo_ads_display.exceptions import ApiException
# import models into sdk package
from yahoo_ads_display.models.account import Account
from yahoo_ads_display.models.account_ad_product import AccountAdProduct
from yahoo_ads_display.models.account_ad_product_service_ad_product import AccountAdProductServiceAdProduct
from yahoo_ads_display.models.account_ad_product_service_get_response import AccountAdProductServiceGetResponse
from yahoo_ads_display.models.account_ad_product_service_page import AccountAdProductServicePage
from yahoo_ads_display.models.account_ad_product_service_selector import AccountAdProductServiceSelector
from yahoo_ads_display.models.account_ad_product_service_value import AccountAdProductServiceValue
from yahoo_ads_display.models.account_service_auth_type import AccountServiceAuthType
from yahoo_ads_display.models.account_service_auto_tagging_enabled import AccountServiceAutoTaggingEnabled
from yahoo_ads_display.models.account_service_budget import AccountServiceBudget
from yahoo_ads_display.models.account_service_delivery_status import AccountServiceDeliveryStatus
from yahoo_ads_display.models.account_service_get_response import AccountServiceGetResponse
from yahoo_ads_display.models.account_service_include_test_account import AccountServiceIncludeTestAccount
from yahoo_ads_display.models.account_service_is_test_account import AccountServiceIsTestAccount
from yahoo_ads_display.models.account_service_limit_charge_type import AccountServiceLimitChargeType
from yahoo_ads_display.models.account_service_mutate_response import AccountServiceMutateResponse
from yahoo_ads_display.models.account_service_operation import AccountServiceOperation
from yahoo_ads_display.models.account_service_page import AccountServicePage
from yahoo_ads_display.models.account_service_return_value import AccountServiceReturnValue
from yahoo_ads_display.models.account_service_selector import AccountServiceSelector
from yahoo_ads_display.models.account_service_status import AccountServiceStatus
from yahoo_ads_display.models.account_service_type import AccountServiceType
from yahoo_ads_display.models.account_service_value import AccountServiceValue
from yahoo_ads_display.models.ad_group import AdGroup
from yahoo_ads_display.models.ad_group_ad import AdGroupAd
from yahoo_ads_display.models.ad_group_ad_label import AdGroupAdLabel
from yahoo_ads_display.models.ad_group_ad_label_service_mutate_response import AdGroupAdLabelServiceMutateResponse
from yahoo_ads_display.models.ad_group_ad_label_service_operation import AdGroupAdLabelServiceOperation
from yahoo_ads_display.models.ad_group_ad_label_service_return_value import AdGroupAdLabelServiceReturnValue
from yahoo_ads_display.models.ad_group_ad_label_service_value import AdGroupAdLabelServiceValue
from yahoo_ads_display.models.ad_group_ad_service_ad import AdGroupAdServiceAd
from yahoo_ads_display.models.ad_group_ad_service_ad_style import AdGroupAdServiceAdStyle
from yahoo_ads_display.models.ad_group_ad_service_ad_type import AdGroupAdServiceAdType
from yahoo_ads_display.models.ad_group_ad_service_approval_status import AdGroupAdServiceApprovalStatus
from yahoo_ads_display.models.ad_group_ad_service_banner_image_ad import AdGroupAdServiceBannerImageAd
from yahoo_ads_display.models.ad_group_ad_service_banner_video_ad import AdGroupAdServiceBannerVideoAd
from yahoo_ads_display.models.ad_group_ad_service_bid import AdGroupAdServiceBid
from yahoo_ads_display.models.ad_group_ad_service_bidding_strategy_type import AdGroupAdServiceBiddingStrategyType
from yahoo_ads_display.models.ad_group_ad_service_button_text import AdGroupAdServiceButtonText
from yahoo_ads_display.models.ad_group_ad_service_campaign_goal_filter_type import AdGroupAdServiceCampaignGoalFilterType
from yahoo_ads_display.models.ad_group_ad_service_carrier_name import AdGroupAdServiceCarrierName
from yahoo_ads_display.models.ad_group_ad_service_dynamic_ad import AdGroupAdServiceDynamicAd
from yahoo_ads_display.models.ad_group_ad_service_get_response import AdGroupAdServiceGetResponse
from yahoo_ads_display.models.ad_group_ad_service_is_remove_flg import AdGroupAdServiceIsRemoveFlg
from yahoo_ads_display.models.ad_group_ad_service_label import AdGroupAdServiceLabel
from yahoo_ads_display.models.ad_group_ad_service_manual_cpc_ad_group_ad_bid import AdGroupAdServiceManualCPCAdGroupAdBid
from yahoo_ads_display.models.ad_group_ad_service_manual_cpv_ad_group_ad_bid import AdGroupAdServiceManualCPVAdGroupAdBid
from yahoo_ads_display.models.ad_group_ad_service_mobile_ad import AdGroupAdServiceMobileAd
from yahoo_ads_display.models.ad_group_ad_service_mutate_response import AdGroupAdServiceMutateResponse
from yahoo_ads_display.models.ad_group_ad_service_operation import AdGroupAdServiceOperation
from yahoo_ads_display.models.ad_group_ad_service_page import AdGroupAdServicePage
from yahoo_ads_display.models.ad_group_ad_service_pos_ad import AdGroupAdServicePosAd
from yahoo_ads_display.models.ad_group_ad_service_responsive_image_ad import AdGroupAdServiceResponsiveImageAd
from yahoo_ads_display.models.ad_group_ad_service_responsive_video_ad import AdGroupAdServiceResponsiveVideoAd
from yahoo_ads_display.models.ad_group_ad_service_return_value import AdGroupAdServiceReturnValue
from yahoo_ads_display.models.ad_group_ad_service_selector import AdGroupAdServiceSelector
from yahoo_ads_display.models.ad_group_ad_service_static_frame_ad import AdGroupAdServiceStaticFrameAd
from yahoo_ads_display.models.ad_group_ad_service_text_ad import AdGroupAdServiceTextAd
from yahoo_ads_display.models.ad_group_ad_service_user_status import AdGroupAdServiceUserStatus
from yahoo_ads_display.models.ad_group_ad_service_value import AdGroupAdServiceValue
from yahoo_ads_display.models.ad_group_label import AdGroupLabel
from yahoo_ads_display.models.ad_group_label_service_mutate_response import AdGroupLabelServiceMutateResponse
from yahoo_ads_display.models.ad_group_label_service_operation import AdGroupLabelServiceOperation
from yahoo_ads_display.models.ad_group_label_service_return_value import AdGroupLabelServiceReturnValue
from yahoo_ads_display.models.ad_group_label_service_value import AdGroupLabelServiceValue
from yahoo_ads_display.models.ad_group_service_auto_conversion_optimizer import AdGroupServiceAutoConversionOptimizer
from yahoo_ads_display.models.ad_group_service_bid import AdGroupServiceBid
from yahoo_ads_display.models.ad_group_service_bidding_strategy import AdGroupServiceBiddingStrategy
from yahoo_ads_display.models.ad_group_service_campaign_bidding_strategy_type import AdGroupServiceCampaignBiddingStrategyType
from yahoo_ads_display.models.ad_group_service_campaign_goal_filter_type import AdGroupServiceCampaignGoalFilterType
from yahoo_ads_display.models.ad_group_service_conversion_optimizer import AdGroupServiceConversionOptimizer
from yahoo_ads_display.models.ad_group_service_device_app_type import AdGroupServiceDeviceAppType
from yahoo_ads_display.models.ad_group_service_device_os_type import AdGroupServiceDeviceOsType
from yahoo_ads_display.models.ad_group_service_device_type import AdGroupServiceDeviceType
from yahoo_ads_display.models.ad_group_service_dynamic_image_extensions import AdGroupServiceDynamicImageExtensions
from yahoo_ads_display.models.ad_group_service_eligibility_flg import AdGroupServiceEligibilityFlg
from yahoo_ads_display.models.ad_group_service_get_response import AdGroupServiceGetResponse
from yahoo_ads_display.models.ad_group_service_label import AdGroupServiceLabel
from yahoo_ads_display.models.ad_group_service_manual_cpc_bid import AdGroupServiceManualCPCBid
from yahoo_ads_display.models.ad_group_service_manual_cpv_bid import AdGroupServiceManualCPVBid
from yahoo_ads_display.models.ad_group_service_manual_conversion_optimizer import AdGroupServiceManualConversionOptimizer
from yahoo_ads_display.models.ad_group_service_mutate_response import AdGroupServiceMutateResponse
from yahoo_ads_display.models.ad_group_service_none_conversion_optimizer import AdGroupServiceNoneConversionOptimizer
from yahoo_ads_display.models.ad_group_service_operation import AdGroupServiceOperation
from yahoo_ads_display.models.ad_group_service_optimizer_type import AdGroupServiceOptimizerType
from yahoo_ads_display.models.ad_group_service_page import AdGroupServicePage
from yahoo_ads_display.models.ad_group_service_return_value import AdGroupServiceReturnValue
from yahoo_ads_display.models.ad_group_service_selector import AdGroupServiceSelector
from yahoo_ads_display.models.ad_group_service_smart_device_carrier import AdGroupServiceSmartDeviceCarrier
from yahoo_ads_display.models.ad_group_service_type import AdGroupServiceType
from yahoo_ads_display.models.ad_group_service_user_status import AdGroupServiceUserStatus
from yahoo_ads_display.models.ad_group_service_value import AdGroupServiceValue
from yahoo_ads_display.models.ad_group_target import AdGroupTarget
from yahoo_ads_display.models.ad_group_target_return_value import AdGroupTargetReturnValue
from yahoo_ads_display.models.ad_group_target_service_ad_schedule_target import AdGroupTargetServiceAdScheduleTarget
from yahoo_ads_display.models.ad_group_target_service_age import AdGroupTargetServiceAge
from yahoo_ads_display.models.ad_group_target_service_age_target import AdGroupTargetServiceAgeTarget
from yahoo_ads_display.models.ad_group_target_service_app_target import AdGroupTargetServiceAppTarget
from yahoo_ads_display.models.ad_group_target_service_audience_category_target import AdGroupTargetServiceAudienceCategoryTarget
from yahoo_ads_display.models.ad_group_target_service_carrier_target import AdGroupTargetServiceCarrierTarget
from yahoo_ads_display.models.ad_group_target_service_carrier_type import AdGroupTargetServiceCarrierType
from yahoo_ads_display.models.ad_group_target_service_day_of_week import AdGroupTargetServiceDayOfWeek
from yahoo_ads_display.models.ad_group_target_service_device_app_type import AdGroupTargetServiceDeviceAppType
from yahoo_ads_display.models.ad_group_target_service_device_os_type import AdGroupTargetServiceDeviceOsType
from yahoo_ads_display.models.ad_group_target_service_device_target import AdGroupTargetServiceDeviceTarget
from yahoo_ads_display.models.ad_group_target_service_device_type import AdGroupTargetServiceDeviceType
from yahoo_ads_display.models.ad_group_target_service_estimate_flg import AdGroupTargetServiceEstimateFlg
from yahoo_ads_display.models.ad_group_target_service_gender import AdGroupTargetServiceGender
from yahoo_ads_display.models.ad_group_target_service_gender_target import AdGroupTargetServiceGenderTarget
from yahoo_ads_display.models.ad_group_target_service_geo_target import AdGroupTargetServiceGeoTarget
from yahoo_ads_display.models.ad_group_target_service_get_response import AdGroupTargetServiceGetResponse
from yahoo_ads_display.models.ad_group_target_service_interest_category_target import AdGroupTargetServiceInterestCategoryTarget
from yahoo_ads_display.models.ad_group_target_service_mutate_response import AdGroupTargetServiceMutateResponse
from yahoo_ads_display.models.ad_group_target_service_operation import AdGroupTargetServiceOperation
from yahoo_ads_display.models.ad_group_target_service_os_target import AdGroupTargetServiceOsTarget
from yahoo_ads_display.models.ad_group_target_service_os_version_target import AdGroupTargetServiceOsVersionTarget
from yahoo_ads_display.models.ad_group_target_service_page import AdGroupTargetServicePage
from yahoo_ads_display.models.ad_group_target_service_placement_target import AdGroupTargetServicePlacementTarget
from yahoo_ads_display.models.ad_group_target_service_placement_url_list_type import AdGroupTargetServicePlacementUrlListType
from yahoo_ads_display.models.ad_group_target_service_search_target import AdGroupTargetServiceSearchTarget
from yahoo_ads_display.models.ad_group_target_service_selector import AdGroupTargetServiceSelector
from yahoo_ads_display.models.ad_group_target_service_site_category_target import AdGroupTargetServiceSiteCategoryTarget
from yahoo_ads_display.models.ad_group_target_service_site_retargeting_target import AdGroupTargetServiceSiteRetargetingTarget
from yahoo_ads_display.models.ad_group_target_service_target import AdGroupTargetServiceTarget
from yahoo_ads_display.models.ad_group_target_service_target_list_deliver_type import AdGroupTargetServiceTargetListDeliverType
from yahoo_ads_display.models.ad_group_target_service_target_type import AdGroupTargetServiceTargetType
from yahoo_ads_display.models.ad_group_target_service_value import AdGroupTargetServiceValue
from yahoo_ads_display.models.audit_log_service_date_range import AuditLogServiceDateRange
from yahoo_ads_display.models.audit_log_service_download_selector import AuditLogServiceDownloadSelector
from yahoo_ads_display.models.audit_log_service_get_response import AuditLogServiceGetResponse
from yahoo_ads_display.models.audit_log_service_job import AuditLogServiceJob
from yahoo_ads_display.models.audit_log_service_job_status import AuditLogServiceJobStatus
from yahoo_ads_display.models.audit_log_service_lang import AuditLogServiceLang
from yahoo_ads_display.models.audit_log_service_mutate_response import AuditLogServiceMutateResponse
from yahoo_ads_display.models.audit_log_service_operation import AuditLogServiceOperation
from yahoo_ads_display.models.audit_log_service_page import AuditLogServicePage
from yahoo_ads_display.models.audit_log_service_return_value import AuditLogServiceReturnValue
from yahoo_ads_display.models.audit_log_service_selector import AuditLogServiceSelector
from yahoo_ads_display.models.audit_log_service_update_source import AuditLogServiceUpdateSource
from yahoo_ads_display.models.audit_log_service_value import AuditLogServiceValue
from yahoo_ads_display.models.balance import Balance
from yahoo_ads_display.models.balance_service_get_response import BalanceServiceGetResponse
from yahoo_ads_display.models.balance_service_page import BalanceServicePage
from yahoo_ads_display.models.balance_service_selector import BalanceServiceSelector
from yahoo_ads_display.models.balance_service_value import BalanceServiceValue
from yahoo_ads_display.models.campaign import Campaign
from yahoo_ads_display.models.campaign_label import CampaignLabel
from yahoo_ads_display.models.campaign_label_service_mutate_response import CampaignLabelServiceMutateResponse
from yahoo_ads_display.models.campaign_label_service_operation import CampaignLabelServiceOperation
from yahoo_ads_display.models.campaign_label_service_return_value import CampaignLabelServiceReturnValue
from yahoo_ads_display.models.campaign_label_service_value import CampaignLabelServiceValue
from yahoo_ads_display.models.campaign_migration_service_download_file_selector import CampaignMigrationServiceDownloadFileSelector
from yahoo_ads_display.models.campaign_migration_service_download_selector import CampaignMigrationServiceDownloadSelector
from yahoo_ads_display.models.campaign_migration_service_get_response import CampaignMigrationServiceGetResponse
from yahoo_ads_display.models.campaign_migration_service_job import CampaignMigrationServiceJob
from yahoo_ads_display.models.campaign_migration_service_job_status import CampaignMigrationServiceJobStatus
from yahoo_ads_display.models.campaign_migration_service_job_value import CampaignMigrationServiceJobValue
from yahoo_ads_display.models.campaign_migration_service_lang import CampaignMigrationServiceLang
from yahoo_ads_display.models.campaign_migration_service_page import CampaignMigrationServicePage
from yahoo_ads_display.models.campaign_migration_service_scope import CampaignMigrationServiceScope
from yahoo_ads_display.models.campaign_migration_service_selector import CampaignMigrationServiceSelector
from yahoo_ads_display.models.campaign_migration_service_upload_response import CampaignMigrationServiceUploadResponse
from yahoo_ads_display.models.campaign_migration_service_upload_return_value import CampaignMigrationServiceUploadReturnValue
from yahoo_ads_display.models.campaign_service_auto_campaign_conversion_optimizer import CampaignServiceAutoCampaignConversionOptimizer
from yahoo_ads_display.models.campaign_service_bidding_strategy import CampaignServiceBiddingStrategy
from yahoo_ads_display.models.campaign_service_bidding_strategy_type import CampaignServiceBiddingStrategyType
from yahoo_ads_display.models.campaign_service_budget import CampaignServiceBudget
from yahoo_ads_display.models.campaign_service_budget_delivery_method import CampaignServiceBudgetDeliveryMethod
from yahoo_ads_display.models.campaign_service_campaign_bidding_strategy import CampaignServiceCampaignBiddingStrategy
from yahoo_ads_display.models.campaign_service_campaign_bidding_strategy_type import CampaignServiceCampaignBiddingStrategyType
from yahoo_ads_display.models.campaign_service_conversion_optimizer import CampaignServiceConversionOptimizer
from yahoo_ads_display.models.campaign_service_conversion_optimizer_eligibility_flg import CampaignServiceConversionOptimizerEligibilityFlg
from yahoo_ads_display.models.campaign_service_conversion_optimizer_training_status import CampaignServiceConversionOptimizerTrainingStatus
from yahoo_ads_display.models.campaign_service_conversion_optimizer_type import CampaignServiceConversionOptimizerType
from yahoo_ads_display.models.campaign_service_device_os_type import CampaignServiceDeviceOsType
from yahoo_ads_display.models.campaign_service_frequency_cap import CampaignServiceFrequencyCap
from yahoo_ads_display.models.campaign_service_frequency_level import CampaignServiceFrequencyLevel
from yahoo_ads_display.models.campaign_service_frequency_time_unit import CampaignServiceFrequencyTimeUnit
from yahoo_ads_display.models.campaign_service_get_response import CampaignServiceGetResponse
from yahoo_ads_display.models.campaign_service_goal_filter_type import CampaignServiceGoalFilterType
from yahoo_ads_display.models.campaign_service_label import CampaignServiceLabel
from yahoo_ads_display.models.campaign_service_manual_campaign_conversion_optimizer import CampaignServiceManualCampaignConversionOptimizer
from yahoo_ads_display.models.campaign_service_mutate_response import CampaignServiceMutateResponse
from yahoo_ads_display.models.campaign_service_operation import CampaignServiceOperation
from yahoo_ads_display.models.campaign_service_page import CampaignServicePage
from yahoo_ads_display.models.campaign_service_return_value import CampaignServiceReturnValue
from yahoo_ads_display.models.campaign_service_selector import CampaignServiceSelector
from yahoo_ads_display.models.campaign_service_serving_status import CampaignServiceServingStatus
from yahoo_ads_display.models.campaign_service_type import CampaignServiceType
from yahoo_ads_display.models.campaign_service_user_status import CampaignServiceUserStatus
from yahoo_ads_display.models.campaign_service_value import CampaignServiceValue
from yahoo_ads_display.models.campaign_service_viewable_frequency_cap import CampaignServiceViewableFrequencyCap
from yahoo_ads_display.models.conversion_tracker import ConversionTracker
from yahoo_ads_display.models.conversion_tracker_service_app_conversion import ConversionTrackerServiceAppConversion
from yahoo_ads_display.models.conversion_tracker_service_app_conversion_platform import ConversionTrackerServiceAppConversionPlatform
from yahoo_ads_display.models.conversion_tracker_service_app_conversion_type import ConversionTrackerServiceAppConversionType
from yahoo_ads_display.models.conversion_tracker_service_category import ConversionTrackerServiceCategory
from yahoo_ads_display.models.conversion_tracker_service_counting_type import ConversionTrackerServiceCountingType
from yahoo_ads_display.models.conversion_tracker_service_exclude_from_bidding import ConversionTrackerServiceExcludeFromBidding
from yahoo_ads_display.models.conversion_tracker_service_get_response import ConversionTrackerServiceGetResponse
from yahoo_ads_display.models.conversion_tracker_service_mutate_response import ConversionTrackerServiceMutateResponse
from yahoo_ads_display.models.conversion_tracker_service_operation import ConversionTrackerServiceOperation
from yahoo_ads_display.models.conversion_tracker_service_page import ConversionTrackerServicePage
from yahoo_ads_display.models.conversion_tracker_service_period import ConversionTrackerServicePeriod
from yahoo_ads_display.models.conversion_tracker_service_period_datetime import ConversionTrackerServicePeriodDatetime
from yahoo_ads_display.models.conversion_tracker_service_return_value import ConversionTrackerServiceReturnValue
from yahoo_ads_display.models.conversion_tracker_service_selector import ConversionTrackerServiceSelector
from yahoo_ads_display.models.conversion_tracker_service_stats_period import ConversionTrackerServiceStatsPeriod
from yahoo_ads_display.models.conversion_tracker_service_stats_period_custom_date import ConversionTrackerServiceStatsPeriodCustomDate
from yahoo_ads_display.models.conversion_tracker_service_status import ConversionTrackerServiceStatus
from yahoo_ads_display.models.conversion_tracker_service_type import ConversionTrackerServiceType
from yahoo_ads_display.models.conversion_tracker_service_value import ConversionTrackerServiceValue
from yahoo_ads_display.models.conversion_tracker_service_web_conversion import ConversionTrackerServiceWebConversion
from yahoo_ads_display.models.conversion_tracker_service_web_conversion_snippet import ConversionTrackerServiceWebConversionSnippet
from yahoo_ads_display.models.conversion_tracker_service_web_conversion_snippet_type import ConversionTrackerServiceWebConversionSnippetType
from yahoo_ads_display.models.dictionary_service_audience_category import DictionaryServiceAudienceCategory
from yahoo_ads_display.models.dictionary_service_audience_category_page import DictionaryServiceAudienceCategoryPage
from yahoo_ads_display.models.dictionary_service_audience_category_value import DictionaryServiceAudienceCategoryValue
from yahoo_ads_display.models.dictionary_service_category import DictionaryServiceCategory
from yahoo_ads_display.models.dictionary_service_category_child import DictionaryServiceCategoryChild
from yahoo_ads_display.models.dictionary_service_category_page import DictionaryServiceCategoryPage
from yahoo_ads_display.models.dictionary_service_category_selector import DictionaryServiceCategorySelector
from yahoo_ads_display.models.dictionary_service_category_value import DictionaryServiceCategoryValue
from yahoo_ads_display.models.dictionary_service_device_os_type import DictionaryServiceDeviceOsType
from yahoo_ads_display.models.dictionary_service_disapproval_reason import DictionaryServiceDisapprovalReason
from yahoo_ads_display.models.dictionary_service_disapproval_reason_page import DictionaryServiceDisapprovalReasonPage
from yahoo_ads_display.models.dictionary_service_disapproval_reason_selector import DictionaryServiceDisapprovalReasonSelector
from yahoo_ads_display.models.dictionary_service_disapproval_reason_value import DictionaryServiceDisapprovalReasonValue
from yahoo_ads_display.models.dictionary_service_feed_item_google_product_category import DictionaryServiceFeedItemGoogleProductCategory
from yahoo_ads_display.models.dictionary_service_feed_item_google_product_category_page import DictionaryServiceFeedItemGoogleProductCategoryPage
from yahoo_ads_display.models.dictionary_service_feed_item_google_product_category_selector import DictionaryServiceFeedItemGoogleProductCategorySelector
from yahoo_ads_display.models.dictionary_service_feed_item_google_product_category_value import DictionaryServiceFeedItemGoogleProductCategoryValue
from yahoo_ads_display.models.dictionary_service_geographic_location import DictionaryServiceGeographicLocation
from yahoo_ads_display.models.dictionary_service_geographic_location_page import DictionaryServiceGeographicLocationPage
from yahoo_ads_display.models.dictionary_service_geographic_location_selector import DictionaryServiceGeographicLocationSelector
from yahoo_ads_display.models.dictionary_service_geographic_location_type import DictionaryServiceGeographicLocationType
from yahoo_ads_display.models.dictionary_service_geographic_location_value import DictionaryServiceGeographicLocationValue
from yahoo_ads_display.models.dictionary_service_get_audience_category_response import DictionaryServiceGetAudienceCategoryResponse
from yahoo_ads_display.models.dictionary_service_get_disapproval_reason_response import DictionaryServiceGetDisapprovalReasonResponse
from yahoo_ads_display.models.dictionary_service_get_feed_item_google_product_category_response import DictionaryServiceGetFeedItemGoogleProductCategoryResponse
from yahoo_ads_display.models.dictionary_service_get_geographic_location_response import DictionaryServiceGetGeographicLocationResponse
from yahoo_ads_display.models.dictionary_service_get_interest_category_response import DictionaryServiceGetInterestCategoryResponse
from yahoo_ads_display.models.dictionary_service_get_media_ad_format_response import DictionaryServiceGetMediaAdFormatResponse
from yahoo_ads_display.models.dictionary_service_get_os_version_response import DictionaryServiceGetOsVersionResponse
from yahoo_ads_display.models.dictionary_service_get_site_category_response import DictionaryServiceGetSiteCategoryResponse
from yahoo_ads_display.models.dictionary_service_get_third_party_tracking_domain_response import DictionaryServiceGetThirdPartyTrackingDomainResponse
from yahoo_ads_display.models.dictionary_service_lang import DictionaryServiceLang
from yahoo_ads_display.models.dictionary_service_media_ad_format import DictionaryServiceMediaAdFormat
from yahoo_ads_display.models.dictionary_service_media_ad_format_page import DictionaryServiceMediaAdFormatPage
from yahoo_ads_display.models.dictionary_service_media_ad_format_value import DictionaryServiceMediaAdFormatValue
from yahoo_ads_display.models.dictionary_service_os_version import DictionaryServiceOsVersion
from yahoo_ads_display.models.dictionary_service_os_version_page import DictionaryServiceOsVersionPage
from yahoo_ads_display.models.dictionary_service_os_version_selector import DictionaryServiceOsVersionSelector
from yahoo_ads_display.models.dictionary_service_os_version_value import DictionaryServiceOsVersionValue
from yahoo_ads_display.models.dictionary_service_third_party_tracking_domain import DictionaryServiceThirdPartyTrackingDomain
from yahoo_ads_display.models.dictionary_service_third_party_tracking_domain_page import DictionaryServiceThirdPartyTrackingDomainPage
from yahoo_ads_display.models.dictionary_service_third_party_tracking_domain_value import DictionaryServiceThirdPartyTrackingDomainValue
from yahoo_ads_display.models.error import Error
from yahoo_ads_display.models.error_detail import ErrorDetail
from yahoo_ads_display.models.feed import Feed
from yahoo_ads_display.models.feed_data_service_download_error_file_selector import FeedDataServiceDownloadErrorFileSelector
from yahoo_ads_display.models.feed_data_service_file_upload_date_range import FeedDataServiceFileUploadDateRange
from yahoo_ads_display.models.feed_data_service_file_upload_src import FeedDataServiceFileUploadSrc
from yahoo_ads_display.models.feed_data_service_file_upload_status import FeedDataServiceFileUploadStatus
from yahoo_ads_display.models.feed_data_service_get_response import FeedDataServiceGetResponse
from yahoo_ads_display.models.feed_data_service_item_list_upload_type import FeedDataServiceItemListUploadType
from yahoo_ads_display.models.feed_data_service_page import FeedDataServicePage
from yahoo_ads_display.models.feed_data_service_record import FeedDataServiceRecord
from yahoo_ads_display.models.feed_data_service_selector import FeedDataServiceSelector
from yahoo_ads_display.models.feed_data_service_upload_response import FeedDataServiceUploadResponse
from yahoo_ads_display.models.feed_data_service_upload_return_value import FeedDataServiceUploadReturnValue
from yahoo_ads_display.models.feed_data_service_value import FeedDataServiceValue
from yahoo_ads_display.models.feed_ftp import FeedFtp
from yahoo_ads_display.models.feed_ftp_request import FeedFtpRequest
from yahoo_ads_display.models.feed_ftp_request_service_mutate_response import FeedFtpRequestServiceMutateResponse
from yahoo_ads_display.models.feed_ftp_request_service_operation import FeedFtpRequestServiceOperation
from yahoo_ads_display.models.feed_ftp_request_service_return_value import FeedFtpRequestServiceReturnValue
from yahoo_ads_display.models.feed_ftp_request_service_value import FeedFtpRequestServiceValue
from yahoo_ads_display.models.feed_ftp_service_active_status import FeedFtpServiceActiveStatus
from yahoo_ads_display.models.feed_ftp_service_get_response import FeedFtpServiceGetResponse
from yahoo_ads_display.models.feed_ftp_service_item_list_upload_type import FeedFtpServiceItemListUploadType
from yahoo_ads_display.models.feed_ftp_service_mutate_response import FeedFtpServiceMutateResponse
from yahoo_ads_display.models.feed_ftp_service_operation import FeedFtpServiceOperation
from yahoo_ads_display.models.feed_ftp_service_page import FeedFtpServicePage
from yahoo_ads_display.models.feed_ftp_service_return_value import FeedFtpServiceReturnValue
from yahoo_ads_display.models.feed_ftp_service_schedule import FeedFtpServiceSchedule
from yahoo_ads_display.models.feed_ftp_service_schedule_daily import FeedFtpServiceScheduleDaily
from yahoo_ads_display.models.feed_ftp_service_schedule_hourly import FeedFtpServiceScheduleHourly
from yahoo_ads_display.models.feed_ftp_service_schedule_type import FeedFtpServiceScheduleType
from yahoo_ads_display.models.feed_ftp_service_schedule_week import FeedFtpServiceScheduleWeek
from yahoo_ads_display.models.feed_ftp_service_schedule_weekly import FeedFtpServiceScheduleWeekly
from yahoo_ads_display.models.feed_ftp_service_selector import FeedFtpServiceSelector
from yahoo_ads_display.models.feed_ftp_service_value import FeedFtpServiceValue
from yahoo_ads_display.models.feed_item import FeedItem
from yahoo_ads_display.models.feed_item_service_availability import FeedItemServiceAvailability
from yahoo_ads_display.models.feed_item_service_is_remove_flg import FeedItemServiceIsRemoveFlg
from yahoo_ads_display.models.feed_item_service_mutate_response import FeedItemServiceMutateResponse
from yahoo_ads_display.models.feed_item_service_operation import FeedItemServiceOperation
from yahoo_ads_display.models.feed_item_service_return_value import FeedItemServiceReturnValue
from yahoo_ads_display.models.feed_item_service_value import FeedItemServiceValue
from yahoo_ads_display.models.feed_service_control_type import FeedServiceControlType
from yahoo_ads_display.models.feed_service_download_dis_approval_reason_list_selector import FeedServiceDownloadDisApprovalReasonListSelector
from yahoo_ads_display.models.feed_service_get_response import FeedServiceGetResponse
from yahoo_ads_display.models.feed_service_mutate_response import FeedServiceMutateResponse
from yahoo_ads_display.models.feed_service_operation import FeedServiceOperation
from yahoo_ads_display.models.feed_service_page import FeedServicePage
from yahoo_ads_display.models.feed_service_return_value import FeedServiceReturnValue
from yahoo_ads_display.models.feed_service_selector import FeedServiceSelector
from yahoo_ads_display.models.feed_service_source_type import FeedServiceSourceType
from yahoo_ads_display.models.feed_service_upload_limit import FeedServiceUploadLimit
from yahoo_ads_display.models.feed_service_value import FeedServiceValue
from yahoo_ads_display.models.feed_set import FeedSet
from yahoo_ads_display.models.feed_set_service_compare_operator import FeedSetServiceCompareOperator
from yahoo_ads_display.models.feed_set_service_condition import FeedSetServiceCondition
from yahoo_ads_display.models.feed_set_service_condition_set import FeedSetServiceConditionSet
from yahoo_ads_display.models.feed_set_service_condition_type import FeedSetServiceConditionType
from yahoo_ads_display.models.feed_set_service_get_response import FeedSetServiceGetResponse
from yahoo_ads_display.models.feed_set_service_mutate_response import FeedSetServiceMutateResponse
from yahoo_ads_display.models.feed_set_service_operation import FeedSetServiceOperation
from yahoo_ads_display.models.feed_set_service_page import FeedSetServicePage
from yahoo_ads_display.models.feed_set_service_return_value import FeedSetServiceReturnValue
from yahoo_ads_display.models.feed_set_service_selector import FeedSetServiceSelector
from yahoo_ads_display.models.feed_set_service_value import FeedSetServiceValue
from yahoo_ads_display.models.inline_object import InlineObject
from yahoo_ads_display.models.inline_object1 import InlineObject1
from yahoo_ads_display.models.inline_object2 import InlineObject2
from yahoo_ads_display.models.label import Label
from yahoo_ads_display.models.label_service_get_response import LabelServiceGetResponse
from yahoo_ads_display.models.label_service_mutate_response import LabelServiceMutateResponse
from yahoo_ads_display.models.label_service_operation import LabelServiceOperation
from yahoo_ads_display.models.label_service_page import LabelServicePage
from yahoo_ads_display.models.label_service_return_value import LabelServiceReturnValue
from yahoo_ads_display.models.label_service_selector import LabelServiceSelector
from yahoo_ads_display.models.label_service_value import LabelServiceValue
from yahoo_ads_display.models.media_service_approval_status import MediaServiceApprovalStatus
from yahoo_ads_display.models.media_service_campaign_banner_flg import MediaServiceCampaignBannerFlg
from yahoo_ads_display.models.media_service_download_selector import MediaServiceDownloadSelector
from yahoo_ads_display.models.media_service_file_type import MediaServiceFileType
from yahoo_ads_display.models.media_service_get_response import MediaServiceGetResponse
from yahoo_ads_display.models.media_service_image_media import MediaServiceImageMedia
from yahoo_ads_display.models.media_service_logo_flg import MediaServiceLogoFlg
from yahoo_ads_display.models.media_service_mutate_response import MediaServiceMutateResponse
from yahoo_ads_display.models.media_service_operation import MediaServiceOperation
from yahoo_ads_display.models.media_service_page import MediaServicePage
from yahoo_ads_display.models.media_service_record import MediaServiceRecord
from yahoo_ads_display.models.media_service_return_value import MediaServiceReturnValue
from yahoo_ads_display.models.media_service_selector import MediaServiceSelector
from yahoo_ads_display.models.media_service_thumbnail_flg import MediaServiceThumbnailFlg
from yahoo_ads_display.models.media_service_type import MediaServiceType
from yahoo_ads_display.models.media_service_user_status import MediaServiceUserStatus
from yahoo_ads_display.models.media_service_value import MediaServiceValue
from yahoo_ads_display.models.placement_url_idea import PlacementUrlIdea
from yahoo_ads_display.models.placement_url_idea_service_ad_format import PlacementUrlIdeaServiceAdFormat
from yahoo_ads_display.models.placement_url_idea_service_ad_format_conditions import PlacementUrlIdeaServiceAdFormatConditions
from yahoo_ads_display.models.placement_url_idea_service_get_response import PlacementUrlIdeaServiceGetResponse
from yahoo_ads_display.models.placement_url_idea_service_page import PlacementUrlIdeaServicePage
from yahoo_ads_display.models.placement_url_idea_service_selector import PlacementUrlIdeaServiceSelector
from yahoo_ads_display.models.placement_url_idea_service_value import PlacementUrlIdeaServiceValue
from yahoo_ads_display.models.placement_url_list import PlacementUrlList
from yahoo_ads_display.models.placement_url_list_service_get_response import PlacementUrlListServiceGetResponse
from yahoo_ads_display.models.placement_url_list_service_mutate_response import PlacementUrlListServiceMutateResponse
from yahoo_ads_display.models.placement_url_list_service_operation import PlacementUrlListServiceOperation
from yahoo_ads_display.models.placement_url_list_service_page import PlacementUrlListServicePage
from yahoo_ads_display.models.placement_url_list_service_return_value import PlacementUrlListServiceReturnValue
from yahoo_ads_display.models.placement_url_list_service_selector import PlacementUrlListServiceSelector
from yahoo_ads_display.models.placement_url_list_service_unknown_domain_flg import PlacementUrlListServiceUnknownDomainFlg
from yahoo_ads_display.models.placement_url_list_service_url_active_flg import PlacementUrlListServiceUrlActiveFlg
from yahoo_ads_display.models.placement_url_list_service_url_list import PlacementUrlListServiceUrlList
from yahoo_ads_display.models.placement_url_list_service_value import PlacementUrlListServiceValue
from yahoo_ads_display.models.report_definition import ReportDefinition
from yahoo_ads_display.models.report_definition_service_date_range import ReportDefinitionServiceDateRange
from yahoo_ads_display.models.report_definition_service_date_range_type import ReportDefinitionServiceDateRangeType
from yahoo_ads_display.models.report_definition_service_download_encode import ReportDefinitionServiceDownloadEncode
from yahoo_ads_display.models.report_definition_service_download_format import ReportDefinitionServiceDownloadFormat
from yahoo_ads_display.models.report_definition_service_download_selector import ReportDefinitionServiceDownloadSelector
from yahoo_ads_display.models.report_definition_service_field_attribute import ReportDefinitionServiceFieldAttribute
from yahoo_ads_display.models.report_definition_service_field_value import ReportDefinitionServiceFieldValue
from yahoo_ads_display.models.report_definition_service_filter import ReportDefinitionServiceFilter
from yahoo_ads_display.models.report_definition_service_filter_operator import ReportDefinitionServiceFilterOperator
from yahoo_ads_display.models.report_definition_service_frequency_range import ReportDefinitionServiceFrequencyRange
from yahoo_ads_display.models.report_definition_service_get_report_fields import ReportDefinitionServiceGetReportFields
from yahoo_ads_display.models.report_definition_service_get_report_fields_response import ReportDefinitionServiceGetReportFieldsResponse
from yahoo_ads_display.models.report_definition_service_get_response import ReportDefinitionServiceGetResponse
from yahoo_ads_display.models.report_definition_service_job_status import ReportDefinitionServiceJobStatus
from yahoo_ads_display.models.report_definition_service_lang import ReportDefinitionServiceLang
from yahoo_ads_display.models.report_definition_service_mutate_response import ReportDefinitionServiceMutateResponse
from yahoo_ads_display.models.report_definition_service_operation import ReportDefinitionServiceOperation
from yahoo_ads_display.models.report_definition_service_page import ReportDefinitionServicePage
from yahoo_ads_display.models.report_definition_service_report_sort_field import ReportDefinitionServiceReportSortField
from yahoo_ads_display.models.report_definition_service_report_sort_type import ReportDefinitionServiceReportSortType
from yahoo_ads_display.models.report_definition_service_return_value import ReportDefinitionServiceReturnValue
from yahoo_ads_display.models.report_definition_service_selector import ReportDefinitionServiceSelector
from yahoo_ads_display.models.report_definition_service_type import ReportDefinitionServiceType
from yahoo_ads_display.models.report_definition_service_value import ReportDefinitionServiceValue
from yahoo_ads_display.models.report_definition_service_zip import ReportDefinitionServiceZip
from yahoo_ads_display.models.retargeting_list import RetargetingList
from yahoo_ads_display.models.retargeting_list_service_combination import RetargetingListServiceCombination
from yahoo_ads_display.models.retargeting_list_service_combination_target_list import RetargetingListServiceCombinationTargetList
from yahoo_ads_display.models.retargeting_list_service_compare_operator import RetargetingListServiceCompareOperator
from yahoo_ads_display.models.retargeting_list_service_custom_audience_target_list import RetargetingListServiceCustomAudienceTargetList
from yahoo_ads_display.models.retargeting_list_service_delivery_status import RetargetingListServiceDeliveryStatus
from yahoo_ads_display.models.retargeting_list_service_get_response import RetargetingListServiceGetResponse
from yahoo_ads_display.models.retargeting_list_service_is_open import RetargetingListServiceIsOpen
from yahoo_ads_display.models.retargeting_list_service_is_preset import RetargetingListServiceIsPreset
from yahoo_ads_display.models.retargeting_list_service_logical_operator import RetargetingListServiceLogicalOperator
from yahoo_ads_display.models.retargeting_list_service_mutate_response import RetargetingListServiceMutateResponse
from yahoo_ads_display.models.retargeting_list_service_operation import RetargetingListServiceOperation
from yahoo_ads_display.models.retargeting_list_service_page import RetargetingListServicePage
from yahoo_ads_display.models.retargeting_list_service_return_value import RetargetingListServiceReturnValue
from yahoo_ads_display.models.retargeting_list_service_rule import RetargetingListServiceRule
from yahoo_ads_display.models.retargeting_list_service_rule_condition import RetargetingListServiceRuleCondition
from yahoo_ads_display.models.retargeting_list_service_rule_target_list import RetargetingListServiceRuleTargetList
from yahoo_ads_display.models.retargeting_list_service_rule_type import RetargetingListServiceRuleType
from yahoo_ads_display.models.retargeting_list_service_selector import RetargetingListServiceSelector
from yahoo_ads_display.models.retargeting_list_service_similarity_target_list import RetargetingListServiceSimilarityTargetList
from yahoo_ads_display.models.retargeting_list_service_target_list import RetargetingListServiceTargetList
from yahoo_ads_display.models.retargeting_list_service_target_list_data import RetargetingListServiceTargetListData
from yahoo_ads_display.models.retargeting_list_service_target_list_size import RetargetingListServiceTargetListSize
from yahoo_ads_display.models.retargeting_list_service_target_list_size_reaches import RetargetingListServiceTargetListSizeReaches
from yahoo_ads_display.models.retargeting_list_service_target_list_type import RetargetingListServiceTargetListType
from yahoo_ads_display.models.retargeting_list_service_value import RetargetingListServiceValue
from yahoo_ads_display.models.retargeting_tag import RetargetingTag
from yahoo_ads_display.models.retargeting_tag_service_approval_status import RetargetingTagServiceApprovalStatus
from yahoo_ads_display.models.retargeting_tag_service_get_response import RetargetingTagServiceGetResponse
from yahoo_ads_display.models.retargeting_tag_service_mutate_response import RetargetingTagServiceMutateResponse
from yahoo_ads_display.models.retargeting_tag_service_operation import RetargetingTagServiceOperation
from yahoo_ads_display.models.retargeting_tag_service_page import RetargetingTagServicePage
from yahoo_ads_display.models.retargeting_tag_service_return_value import RetargetingTagServiceReturnValue
from yahoo_ads_display.models.retargeting_tag_service_selector import RetargetingTagServiceSelector
from yahoo_ads_display.models.retargeting_tag_service_value import RetargetingTagServiceValue
from yahoo_ads_display.models.search_keyword_idea import SearchKeywordIdea
from yahoo_ads_display.models.search_keyword_idea_service_get_response import SearchKeywordIdeaServiceGetResponse
from yahoo_ads_display.models.search_keyword_idea_service_keyword_frequency import SearchKeywordIdeaServiceKeywordFrequency
from yahoo_ads_display.models.search_keyword_idea_service_keyword_recency import SearchKeywordIdeaServiceKeywordRecency
from yahoo_ads_display.models.search_keyword_idea_service_match_type import SearchKeywordIdeaServiceMatchType
from yahoo_ads_display.models.search_keyword_idea_service_page import SearchKeywordIdeaServicePage
from yahoo_ads_display.models.search_keyword_idea_service_selector import SearchKeywordIdeaServiceSelector
from yahoo_ads_display.models.search_keyword_idea_service_sort_field import SearchKeywordIdeaServiceSortField
from yahoo_ads_display.models.search_keyword_idea_service_sort_type import SearchKeywordIdeaServiceSortType
from yahoo_ads_display.models.search_keyword_idea_service_value import SearchKeywordIdeaServiceValue
from yahoo_ads_display.models.search_keyword_list import SearchKeywordList
from yahoo_ads_display.models.search_keyword_list_service_delivery_status import SearchKeywordListServiceDeliveryStatus
from yahoo_ads_display.models.search_keyword_list_service_get_response import SearchKeywordListServiceGetResponse
from yahoo_ads_display.models.search_keyword_list_service_keyword_frequency import SearchKeywordListServiceKeywordFrequency
from yahoo_ads_display.models.search_keyword_list_service_keyword_recency import SearchKeywordListServiceKeywordRecency
from yahoo_ads_display.models.search_keyword_list_service_mutate_response import SearchKeywordListServiceMutateResponse
from yahoo_ads_display.models.search_keyword_list_service_operation import SearchKeywordListServiceOperation
from yahoo_ads_display.models.search_keyword_list_service_page import SearchKeywordListServicePage
from yahoo_ads_display.models.search_keyword_list_service_return_value import SearchKeywordListServiceReturnValue
from yahoo_ads_display.models.search_keyword_list_service_search_keyword import SearchKeywordListServiceSearchKeyword
from yahoo_ads_display.models.search_keyword_list_service_selector import SearchKeywordListServiceSelector
from yahoo_ads_display.models.search_keyword_list_service_value import SearchKeywordListServiceValue
from yahoo_ads_display.models.stats import Stats
from yahoo_ads_display.models.stats_service_ad_group_stats_value import StatsServiceAdGroupStatsValue
from yahoo_ads_display.models.stats_service_ad_schedule_target import StatsServiceAdScheduleTarget
from yahoo_ads_display.models.stats_service_ad_stats_value import StatsServiceAdStatsValue
from yahoo_ads_display.models.stats_service_age import StatsServiceAge
from yahoo_ads_display.models.stats_service_age_target import StatsServiceAgeTarget
from yahoo_ads_display.models.stats_service_app_target import StatsServiceAppTarget
from yahoo_ads_display.models.stats_service_audience_category_target import StatsServiceAudienceCategoryTarget
from yahoo_ads_display.models.stats_service_campaign_stats_value import StatsServiceCampaignStatsValue
from yahoo_ads_display.models.stats_service_carrier_target import StatsServiceCarrierTarget
from yahoo_ads_display.models.stats_service_carrier_type import StatsServiceCarrierType
from yahoo_ads_display.models.stats_service_day_of_week import StatsServiceDayOfWeek
from yahoo_ads_display.models.stats_service_device_app_type import StatsServiceDeviceAppType
from yahoo_ads_display.models.stats_service_device_os_type import StatsServiceDeviceOsType
from yahoo_ads_display.models.stats_service_device_target import StatsServiceDeviceTarget
from yahoo_ads_display.models.stats_service_device_type import StatsServiceDeviceType
from yahoo_ads_display.models.stats_service_estimate_flg import StatsServiceEstimateFlg
from yahoo_ads_display.models.stats_service_gender import StatsServiceGender
from yahoo_ads_display.models.stats_service_gender_target import StatsServiceGenderTarget
from yahoo_ads_display.models.stats_service_geo_target import StatsServiceGeoTarget
from yahoo_ads_display.models.stats_service_get_response import StatsServiceGetResponse
from yahoo_ads_display.models.stats_service_image_stats_value import StatsServiceImageStatsValue
from yahoo_ads_display.models.stats_service_interest_category_target import StatsServiceInterestCategoryTarget
from yahoo_ads_display.models.stats_service_os_target import StatsServiceOsTarget
from yahoo_ads_display.models.stats_service_os_version_target import StatsServiceOsVersionTarget
from yahoo_ads_display.models.stats_service_page import StatsServicePage
from yahoo_ads_display.models.stats_service_period import StatsServicePeriod
from yahoo_ads_display.models.stats_service_period_custom_date import StatsServicePeriodCustomDate
from yahoo_ads_display.models.stats_service_period_datetime import StatsServicePeriodDatetime
from yahoo_ads_display.models.stats_service_placement_target import StatsServicePlacementTarget
from yahoo_ads_display.models.stats_service_placement_url_list_type import StatsServicePlacementUrlListType
from yahoo_ads_display.models.stats_service_search_target import StatsServiceSearchTarget
from yahoo_ads_display.models.stats_service_selector import StatsServiceSelector
from yahoo_ads_display.models.stats_service_site_category_target import StatsServiceSiteCategoryTarget
from yahoo_ads_display.models.stats_service_site_retargeting_target import StatsServiceSiteRetargetingTarget
from yahoo_ads_display.models.stats_service_stats_period import StatsServiceStatsPeriod
from yahoo_ads_display.models.stats_service_target import StatsServiceTarget
from yahoo_ads_display.models.stats_service_target_list_deliver_type import StatsServiceTargetListDeliverType
from yahoo_ads_display.models.stats_service_target_setting import StatsServiceTargetSetting
from yahoo_ads_display.models.stats_service_target_stats_value import StatsServiceTargetStatsValue
from yahoo_ads_display.models.stats_service_target_type import StatsServiceTargetType
from yahoo_ads_display.models.stats_service_type import StatsServiceType
from yahoo_ads_display.models.stats_service_value import StatsServiceValue
from yahoo_ads_display.models.stats_service_video_stats_value import StatsServiceVideoStatsValue
from yahoo_ads_display.models.video import Video
from yahoo_ads_display.models.video_service_approval_status import VideoServiceApprovalStatus
from yahoo_ads_display.models.video_service_download_selector import VideoServiceDownloadSelector
from yahoo_ads_display.models.video_service_file_type import VideoServiceFileType
from yahoo_ads_display.models.video_service_get_response import VideoServiceGetResponse
from yahoo_ads_display.models.video_service_mutate_response import VideoServiceMutateResponse
from yahoo_ads_display.models.video_service_operation import VideoServiceOperation
from yahoo_ads_display.models.video_service_page import VideoServicePage
from yahoo_ads_display.models.video_service_process_status import VideoServiceProcessStatus
from yahoo_ads_display.models.video_service_quality_type import VideoServiceQualityType
from yahoo_ads_display.models.video_service_return_value import VideoServiceReturnValue
from yahoo_ads_display.models.video_service_selector import VideoServiceSelector
from yahoo_ads_display.models.video_service_setting import VideoServiceSetting
from yahoo_ads_display.models.video_service_upload_data import VideoServiceUploadData
from yahoo_ads_display.models.video_service_upload_response import VideoServiceUploadResponse
from yahoo_ads_display.models.video_service_upload_return_value import VideoServiceUploadReturnValue
from yahoo_ads_display.models.video_service_upload_value import VideoServiceUploadValue
from yahoo_ads_display.models.video_service_user_status import VideoServiceUserStatus
from yahoo_ads_display.models.video_service_value import VideoServiceValue




# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class MediaServiceRecord(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'approval_status': 'MediaServiceApprovalStatus',
        'campaign_banner_flg': 'MediaServiceCampaignBannerFlg',
        'creation_time': 'str',
        'disapproval_reason_codes': 'list[str]',
        'logo_flg': 'MediaServiceLogoFlg',
        'image_media': 'MediaServiceImageMedia',
        'media_id': 'int',
        'media_name': 'str',
        'media_title': 'str',
        'thumbnail_flg': 'MediaServiceThumbnailFlg',
        'user_status': 'MediaServiceUserStatus'
    }

    attribute_map = {
        'account_id': 'accountId',
        'approval_status': 'approvalStatus',
        'campaign_banner_flg': 'campaignBannerFlg',
        'creation_time': 'creationTime',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'logo_flg': 'logoFlg',
        'image_media': 'imageMedia',
        'media_id': 'mediaId',
        'media_name': 'mediaName',
        'media_title': 'mediaTitle',
        'thumbnail_flg': 'thumbnailFlg',
        'user_status': 'userStatus'
    }

    def __init__(self, account_id=None, approval_status=None, campaign_banner_flg=None, creation_time=None, disapproval_reason_codes=None, logo_flg=None, image_media=None, media_id=None, media_name=None, media_title=None, thumbnail_flg=None, user_status=None, local_vars_configuration=None):  # noqa: E501
        """MediaServiceRecord - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._approval_status = None
        self._campaign_banner_flg = None
        self._creation_time = None
        self._disapproval_reason_codes = None
        self._logo_flg = None
        self._image_media = None
        self._media_id = None
        self._media_name = None
        self._media_title = None
        self._thumbnail_flg = None
        self._user_status = None
        self.discriminator = None

        self.account_id = account_id
        self.approval_status = approval_status
        self.campaign_banner_flg = campaign_banner_flg
        self.creation_time = creation_time
        self.disapproval_reason_codes = disapproval_reason_codes
        self.logo_flg = logo_flg
        self.image_media = image_media
        self.media_id = media_id
        self.media_name = media_name
        self.media_title = media_title
        self.thumbnail_flg = thumbnail_flg
        self.user_status = user_status

    @property
    def account_id(self):
        """Gets the account_id of this MediaServiceRecord.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\">Account ID.<br> This field is required in requests. </div>   # noqa: E501

        :return: The account_id of this MediaServiceRecord.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this MediaServiceRecord.

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、リクエストの場合は必須です。 </div> <div lang=\"en\">Account ID.<br> This field is required in requests. </div>   # noqa: E501

        :param account_id: The account_id of this MediaServiceRecord.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def approval_status(self):
        """Gets the approval_status of this MediaServiceRecord.  # noqa: E501


        :return: The approval_status of this MediaServiceRecord.  # noqa: E501
        :rtype: MediaServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this MediaServiceRecord.


        :param approval_status: The approval_status of this MediaServiceRecord.  # noqa: E501
        :type: MediaServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def campaign_banner_flg(self):
        """Gets the campaign_banner_flg of this MediaServiceRecord.  # noqa: E501


        :return: The campaign_banner_flg of this MediaServiceRecord.  # noqa: E501
        :rtype: MediaServiceCampaignBannerFlg
        """
        return self._campaign_banner_flg

    @campaign_banner_flg.setter
    def campaign_banner_flg(self, campaign_banner_flg):
        """Sets the campaign_banner_flg of this MediaServiceRecord.


        :param campaign_banner_flg: The campaign_banner_flg of this MediaServiceRecord.  # noqa: E501
        :type: MediaServiceCampaignBannerFlg
        """

        self._campaign_banner_flg = campaign_banner_flg

    @property
    def creation_time(self):
        """Gets the creation_time of this MediaServiceRecord.  # noqa: E501

        <div lang=\"ja\">入稿日時です。</div> <div lang=\"en\">Date and time of creation.</div>   # noqa: E501

        :return: The creation_time of this MediaServiceRecord.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this MediaServiceRecord.

        <div lang=\"ja\">入稿日時です。</div> <div lang=\"en\">Date and time of creation.</div>   # noqa: E501

        :param creation_time: The creation_time of this MediaServiceRecord.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this MediaServiceRecord.  # noqa: E501

        <div lang=\"ja\">掲載拒否の理由です。</div> <div lang=\"en\">Reason code why it&#39;s disapproved on the review.</div>   # noqa: E501

        :return: The disapproval_reason_codes of this MediaServiceRecord.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this MediaServiceRecord.

        <div lang=\"ja\">掲載拒否の理由です。</div> <div lang=\"en\">Reason code why it&#39;s disapproved on the review.</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this MediaServiceRecord.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def logo_flg(self):
        """Gets the logo_flg of this MediaServiceRecord.  # noqa: E501


        :return: The logo_flg of this MediaServiceRecord.  # noqa: E501
        :rtype: MediaServiceLogoFlg
        """
        return self._logo_flg

    @logo_flg.setter
    def logo_flg(self, logo_flg):
        """Sets the logo_flg of this MediaServiceRecord.


        :param logo_flg: The logo_flg of this MediaServiceRecord.  # noqa: E501
        :type: MediaServiceLogoFlg
        """

        self._logo_flg = logo_flg

    @property
    def image_media(self):
        """Gets the image_media of this MediaServiceRecord.  # noqa: E501


        :return: The image_media of this MediaServiceRecord.  # noqa: E501
        :rtype: MediaServiceImageMedia
        """
        return self._image_media

    @image_media.setter
    def image_media(self, image_media):
        """Sets the image_media of this MediaServiceRecord.


        :param image_media: The image_media of this MediaServiceRecord.  # noqa: E501
        :type: MediaServiceImageMedia
        """

        self._image_media = image_media

    @property
    def media_id(self):
        """Gets the media_id of this MediaServiceRecord.  # noqa: E501

        <div lang=\"ja\">画像IDです。<br> このフィールドは、SETおよびREMOVE時に必須となります。 </div> <div lang=\"en\">Media ID (image ID). <br> This field is required in SET and REMOVE operation. </div>   # noqa: E501

        :return: The media_id of this MediaServiceRecord.  # noqa: E501
        :rtype: int
        """
        return self._media_id

    @media_id.setter
    def media_id(self, media_id):
        """Sets the media_id of this MediaServiceRecord.

        <div lang=\"ja\">画像IDです。<br> このフィールドは、SETおよびREMOVE時に必須となります。 </div> <div lang=\"en\">Media ID (image ID). <br> This field is required in SET and REMOVE operation. </div>   # noqa: E501

        :param media_id: The media_id of this MediaServiceRecord.  # noqa: E501
        :type: int
        """

        self._media_id = media_id

    @property
    def media_name(self):
        """Gets the media_name of this MediaServiceRecord.  # noqa: E501

        <div lang=\"ja\"> 実ファイル名です。<br> このフィールドは、ADD時に必須となります。 </div> <div lang=\"en\">File name. <br> This field is required in ADD operation. </div>   # noqa: E501

        :return: The media_name of this MediaServiceRecord.  # noqa: E501
        :rtype: str
        """
        return self._media_name

    @media_name.setter
    def media_name(self, media_name):
        """Sets the media_name of this MediaServiceRecord.

        <div lang=\"ja\"> 実ファイル名です。<br> このフィールドは、ADD時に必須となります。 </div> <div lang=\"en\">File name. <br> This field is required in ADD operation. </div>   # noqa: E501

        :param media_name: The media_name of this MediaServiceRecord.  # noqa: E501
        :type: str
        """

        self._media_name = media_name

    @property
    def media_title(self):
        """Gets the media_title of this MediaServiceRecord.  # noqa: E501

        <div lang=\"ja\">画像名です。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となります。 </div> <div lang=\"en\">Image name. <br> This field is required in ADD operation, and is optional in SET operation. </div>   # noqa: E501

        :return: The media_title of this MediaServiceRecord.  # noqa: E501
        :rtype: str
        """
        return self._media_title

    @media_title.setter
    def media_title(self, media_title):
        """Sets the media_title of this MediaServiceRecord.

        <div lang=\"ja\">画像名です。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となります。 </div> <div lang=\"en\">Image name. <br> This field is required in ADD operation, and is optional in SET operation. </div>   # noqa: E501

        :param media_title: The media_title of this MediaServiceRecord.  # noqa: E501
        :type: str
        """

        self._media_title = media_title

    @property
    def thumbnail_flg(self):
        """Gets the thumbnail_flg of this MediaServiceRecord.  # noqa: E501


        :return: The thumbnail_flg of this MediaServiceRecord.  # noqa: E501
        :rtype: MediaServiceThumbnailFlg
        """
        return self._thumbnail_flg

    @thumbnail_flg.setter
    def thumbnail_flg(self, thumbnail_flg):
        """Sets the thumbnail_flg of this MediaServiceRecord.


        :param thumbnail_flg: The thumbnail_flg of this MediaServiceRecord.  # noqa: E501
        :type: MediaServiceThumbnailFlg
        """

        self._thumbnail_flg = thumbnail_flg

    @property
    def user_status(self):
        """Gets the user_status of this MediaServiceRecord.  # noqa: E501


        :return: The user_status of this MediaServiceRecord.  # noqa: E501
        :rtype: MediaServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this MediaServiceRecord.


        :param user_status: The user_status of this MediaServiceRecord.  # noqa: E501
        :type: MediaServiceUserStatus
        """

        self._user_status = user_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaServiceRecord):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MediaServiceRecord):
            return True

        return self.to_dict() != other.to_dict()
